use std::time::Duration;

#[derive(Clone, Debug)]
pub enum Color {
    Black,
    White,
}

#[derive(Clone, Debug)]
pub struct Size {
    pub width: u8,
    pub height: u8,
}

pub(crate) struct AppState {
    game: Option<GameState>,
}

impl AppState {
    pub fn new() -> Self {
        Self { game: None }
    }
}

enum Rank {
    Kyu(u8),
    Dan(u8),
    Pro(u8),
}

impl TryFrom<&str> for Rank {
    type Error = String;

    fn try_from(_: &str) -> Result<Rank, Self::Error> {
        Ok(Rank::Kyu(15))
    }
}

impl From<Rank> for String {
    fn from(r: Rank) -> String {
        match r {
            Rank::Kyu(v) => format!("{} kyu", v),
            Rank::Dan(v) => format!("{} dan", v),
            Rank::Pro(v) => format!("{} pro", v),
        }
    }
}

struct Player {
    name: String,
    rank: Rank,
}

pub(crate) struct GameState {
    goban: Vec<Vec<Color>>,
    conversation: Vec<String>,

    white_player: Player,
    black_player: Player,

    white_clock: Duration,
    black_clock: Duration,
}
