use crate::types::{Color, Size};
use crate::ui::types;

#[derive(Clone, Debug)]
pub struct PlayingFieldView {
    pub board: types::GameBoardElement,
    pub player_card_black: types::PlayerCardElement,
    pub player_card_white: types::PlayerCardElement,
    pub chat: types::ChatElement,
    pub message: types::TextFieldElement,
    pub current_player: Color,
}

pub fn playing_field() -> PlayingFieldView {
    let mut spaces = Vec::new();
    (0..19).for_each(|_| spaces.push(Vec::new()));

    let board = types::GameBoardElement {
        size: Size {
            width: 19,
            height: 19,
        },
        spaces,
    };

    let player_card_black = types::PlayerCardElement {
        color: Color::Black,
        name: "Savanni".to_owned(),
        rank: "10k".to_owned(),
        clock: "24:53".to_owned(),
    };

    let player_card_white = types::PlayerCardElement {
        color: Color::White,
        name: "Opal".to_owned(),
        rank: "10k".to_owned(),
        clock: "25:00".to_owned(),
    };

    let chat = types::ChatElement {
        messages: vec![
            "[22:05] Savanni: oops".to_owned(),
            "[22:06] Opal: you know I'll take advantage of that, right?".to_owned(),
        ],
    };
    let message = types::TextFieldElement {};

    PlayingFieldView {
        board,
        player_card_black,
        player_card_white,
        chat,
        message,
        current_player: Color::White,
    }
}
